#!/usr/bin/env perl
#
# SAS Data Quality Set SSL Utility
#
# Copyright (c) 2020 SAS Institute Inc.
#

use strict;
use File::Basename;

# Currently, only SSL 1.0 is supported on non-linux OS
if ($^O ne 'linux') {
	print "This utility is a Linux-only utility.\n";
    exit(0);
}

my $usage = "$0 {1.0|1.1}\n";
my $version = "Data Quality Set SSL Utility version 1.0";

# find where this script is stored
sub get_mydir {
    my ($me, $dir);

    if ($0 =~ m:^/:) {
        $me = $0;
    } else {
        chomp($dir = `pwd`);
        $me = "$dir/$0";
    }
    ($dir = $me) =~ s:(.*)/.*:$1:;
    return $dir;
}

# determine if server is 32-bit or 64-bit
my $home = get_mydir();
$home =~ s:/.$::;
$home =~ s:/+$::;
$home =~ s:/bin$::;

my $sasexe = dirname($home);
$sasexe = dirname($sasexe);
$sasexe = "$sasexe/sasexe";

# defaults
my $gsoap_ver = '2.7';
my $lib_suffix = '.so';
my $gsoap_ssl_type='';
my $gsoap_type='';

# process command line
my $arg = shift;
if ($arg eq '--help') {
    print $usage;
    exit(0);
} elsif ($arg eq '--version') {
    print "$version\n";
    exit(0);
} elsif (lc($arg) eq '1.0') {
    $gsoap_ssl_type = '10x';
    $gsoap_type = $arg;
} elsif (lc($arg) eq '1.1') {
    $gsoap_ssl_type = '11x';
    $gsoap_type = $arg;
} else {
    print $usage;
    exit(1);
}

# ex. libgsoap_ssl11x-2.7.so
my $source_gsoap_lib = "$sasexe/libgsoap_ssl$gsoap_ssl_type-$gsoap_ver$lib_suffix";

# ex libgsoap_ssl-2.7.so
my $target_gsoap_lib = "$sasexe/libgsoap_ssl-$gsoap_ver$lib_suffix";

if (system("cp $source_gsoap_lib $target_gsoap_lib") == 1)
{
	print "Unable to copy file $source_gsoap_lib $target_gsoap_lib\n";
	exit(2);
}

print "Updated SOAP libraries ($gsoap_type)\n";


